@@ -1,32 +1,18 @@
 /*
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "helper.h"
 #include "prefs.h"
+#include "calendarview_debug.h"
 
 #include <Collection>
 #include <Item>
 
 #include <AkonadiCore/CollectionColorAttribute>
+#include <AkonadiCore/CollectionModifyJob>
 
 #include <QIcon>
 #include <QPixmap>
@@ -49,15 +35,20 @@ void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor
     }
 
     const QString id = QString::number(coll.id());
-    if (coll.hasAttribute<Akonadi::CollectionColorAttribute>()) {
-        const Akonadi::CollectionColorAttribute *colorAttr
-            = coll.attribute<Akonadi::CollectionColorAttribute>();
-        if (colorAttr && colorAttr->color().isValid() && (colorAttr->color() == color)) {
-            // It's the same color: we save an invalid color
-            preferences->setResourceColor(id, QColor());
+
+    // Save the color in akonadi (so the resource can even save it server-side)
+    Akonadi::Collection collection = coll;
+    auto *colorAttr
+            = collection.attribute<Akonadi::CollectionColorAttribute>(Akonadi::Collection::AddIfMissing);
+    colorAttr->setColor(color);
+    auto *job = new Akonadi::CollectionModifyJob(collection, nullptr);
+    QObject::connect(job, &Akonadi::CollectionModifyJob::result, [=]() {
+        if (job->error()) {
+            qCWarning(CALENDARVIEW_LOG) << "Failed to set CollectionColorAttribute:" << job->errorString();
         }
-    }
-    // in all other cases, we save the resourceColor
+    });
+
+    // Also save the color in eventviewsrc (mostly historical)
     preferences->setResourceColor(id, color);
 }
 
@@ -74,7 +65,7 @@ QColor EventViews::resourceColor(const Akonadi::Collection &coll, const PrefsPtr
     }
     // Color stored in akonadi
     if (coll.hasAttribute<Akonadi::CollectionColorAttribute>()) {
-        const Akonadi::CollectionColorAttribute *colorAttr
+        const auto *colorAttr
             = coll.attribute<Akonadi::CollectionColorAttribute>();
         if (colorAttr && colorAttr->color().isValid()) {
             return colorAttr->color();
