@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 2007 Till Adam <adam@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "timelineview.h"
@@ -149,16 +133,22 @@ public:
 };
 class GanttItemDelegate : public KGantt::ItemDelegate
 {
+public:
+    explicit GanttItemDelegate(QObject *parent)
+        : KGantt::ItemDelegate(parent)
+    {
+    }
+private:
     void paintGanttItem(QPainter *painter, const KGantt::StyleOptionGanttItem &opt, const QModelIndex &idx) override
     {
         painter->setRenderHints(QPainter::Antialiasing);
         if (!idx.isValid()) {
             return;
         }
-        KGantt::ItemType type = static_cast<KGantt::ItemType>(
+        const KGantt::ItemType type = static_cast<KGantt::ItemType>(
             idx.model()->data(idx, KGantt::ItemTypeRole).toInt());
 
-        QString txt = idx.model()->data(idx, Qt::DisplayRole).toString();
+        const QString txt = idx.model()->data(idx, Qt::DisplayRole).toString();
         QRectF itemRect = opt.itemRect;
         QRectF boundingRect = opt.boundingRect;
         boundingRect.setY(itemRect.y());
@@ -218,8 +208,8 @@ TimelineView::TimelineView(QWidget *parent)
     : EventView(parent)
     , d(new Private(this))
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
-    QSplitter *splitter = new QSplitter(Qt::Horizontal, this);
+    auto *vbox = new QVBoxLayout(this);
+    auto *splitter = new QSplitter(Qt::Horizontal, this);
     d->mLeftView = new QTreeWidget;
     d->mLeftView->setHeader(new GanttHeaderView);
     d->mLeftView->setHeaderLabel(i18n("Calendar"));
@@ -227,12 +217,12 @@ TimelineView::TimelineView(QWidget *parent)
     d->mLeftView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->mLeftView->setUniformRowHeights(true);
 
-    d->mGantt = new KGantt::GraphicsView();
+    d->mGantt = new KGantt::GraphicsView(this);
     splitter->addWidget(d->mLeftView);
     splitter->addWidget(d->mGantt);
     connect(splitter, &QSplitter::splitterMoved,
             d, &Private::splitterMoved);
-    QStandardItemModel *model = new QStandardItemModel(this);
+    auto *model = new QStandardItemModel(this);
 
     d->mRowController = new RowController;
 
@@ -244,7 +234,7 @@ TimelineView::TimelineView(QWidget *parent)
 
     d->mRowController->setModel(model);
     d->mGantt->setRowController(d->mRowController);
-    KGantt::DateTimeGrid *grid = new KGantt::DateTimeGrid;
+    auto *grid = new KGantt::DateTimeGrid();
     grid->setScale(KGantt::DateTimeGrid::ScaleHour);
     grid->setDayWidth(800);
     grid->setRowSeparators(true);
@@ -253,7 +243,7 @@ TimelineView::TimelineView(QWidget *parent)
     d->mGantt->viewport()->setFixedWidth(8000);
 
     d->mGantt->viewport()->installEventFilter(this);
-    d->mGantt->setItemDelegate(new GanttItemDelegate);
+    d->mGantt->setItemDelegate(new GanttItemDelegate(this));
 
     vbox->addWidget(splitter);
 
@@ -301,7 +291,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mEndDate = end;
     d->mHintDate = QDateTime();
 
-    KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
+    auto *grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     grid->setStartDateTime(QDateTime(start));
 #else
@@ -426,17 +416,17 @@ QDate TimelineView::endDate() const
 bool TimelineView::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
-        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        auto *helpEvent = static_cast<QHelpEvent *>(event);
         QGraphicsItem *item = d->mGantt->itemAt(helpEvent->pos());
         if (item) {
             if (item->type() == KGantt::GraphicsItem::Type) {
-                KGantt::GraphicsItem *graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
+                auto *graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
                 const QModelIndex itemIndex = graphicsItem->index();
 
-                QStandardItemModel *itemModel
+                auto *itemModel
                     = qobject_cast<QStandardItemModel *>(d->mGantt->model());
 
-                TimelineSubItem *timelineItem
+                auto *timelineItem
                     = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(),
                                                                       itemIndex.column()));
 
